@@ -25,24 +25,24 @@ class QcisCheck():
 
     def circuit_regular(self):
         regular_exp_map = {
-            'X': r'^X(?:\s(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'Y': r'^Y(?:\s(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'Z': r'^Z(?:\s(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'X2P': r'^X2P(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'X2M': r'^X2M(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'Y2P': r'^Y2P(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'Y2M': r'^Y2M(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'H': r'^H(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'S': r'^S(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'SD': r'^SD(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'T': r'^T(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'TD': r'^TD(?:\s+(?:Q(?:[1][0-2]|[1-9]))){1}$',
-            'CZ': r'^CZ(?:\s+(?:Q(?:[1][0-2]|[1-9]))){2}$',
-            'RX': r'^RX\s(?:Q(?:[1][0-2]|[1-9]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
-            'RY': r'^RY\s(?:Q(?:[1][0-2]|[1-9]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
-            'RZ': r'^RZ\s(?:Q(?:[1][0-2]|[1-9]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
-            'RXY': r'^RXY\s(?:Q(?:[1-5][0-9]|60|[1-9]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
-            'M': r'^M(?:\s+(?:Q(?:[1][0-2]|[1-9])))+$'
+            'X': r'^X(?:\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'Y': r'^Y(?:\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'Z': r'^Z(?:\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'X2P': r'^X2P(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'X2M': r'^X2M(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'Y2P': r'^Y2P(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'Y2M': r'^Y2M(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'H': r'^H(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'S': r'^S(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'SD': r'^SD(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'T': r'^T(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'TD': r'^TD(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){1}$',
+            'CZ': r'^CZ(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))){2}$',
+            'RX': r'^RX\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
+            'RY': r'^RY\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
+            'RZ': r'^RZ\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
+            'RXY': r'^RXY\s(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6]))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))\s([+-]?([0-9]*[.])?([0-9]+|[0-9]+[E][+-]?[0-9]+))$',
+            'M': r'^M(?:\s+(?:Q(?:[1-5][0-9]|60|[1-9]|[6][1-6])))+$'
         }
         self.circuit = self.circuit.upper()
         circuit_list = self.circuit.strip().split('\n')
@@ -74,20 +74,21 @@ class QcisCheck():
                                   for qubit in qubit_list]
                     if not all(is_correct):
                         return False
-            if gate == 'CZ':
-                # CZ指令需要两个qubit相减必须等于1，必须相邻qubit
-                qubit_list = cir.split(' ')[1:]
-                qubit0 = int(re.findall(r'\d+', qubit_list[0])[0])
-                qubit1 = int(re.findall(r'\d+', qubit_list[1])[0])
-                if abs(qubit1 - qubit0) != 1:
-                    return False
+            # if gate == 'CZ':
+            #     # CZ指令需要两个qubit相减必须等于1，必须相邻qubit
+            #     qubit_list = cir.split(' ')[1:]
+            #     qubit0 = int(re.findall(r'\d+', qubit_list[0])[0])
+            #     qubit1 = int(re.findall(r'\d+', qubit_list[1])[0])
+            #     if abs(qubit1 - qubit0) != 1:
+            #         return False
             if gate.startswith('R'):  # RX RY RZ RXY
                 gate_qubit = cir.split(' ')[:2]
+                gate_params = cir.split(' ')[2:]
+                for gate_param in gate_params:
+                    if abs(float(gate_param)) > np.pi:
+                        return False
                 # 匹配出指令中的小数，不包含科学计数法
                 r_result = re.findall(r'([+-]*?[0-9]\.\d*(?!E|e)[0-9])', cir)
-                for r in r_result:
-                    if abs(float(r)) > np.pi:
-                        return False
                 n_result = []
                 for r in r_result:
                     num_list = r.split('.')
@@ -130,7 +131,7 @@ class Account():
         self.machine_name = machine_name
         self.full_expr_record = full_expr_record
         if self.machine_name:
-            cloud_url = 'https://quantumcomputer.ac.cn'
+            cloud_url = 'http://121.37.152.73:7070'
             self.base_url = f'{cloud_url}'
             self.login = self.log_in()
             self.set_machine(self.machine_name)
@@ -204,7 +205,6 @@ class Account():
                     return 1
 
     def create_experiment(self, exp_name):
-        sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
         """create experiment
 
         Args:
@@ -237,6 +237,7 @@ class Account():
             self.exp[lab_id]['lab_name'] = exp_name
             return lab_id
         else:
+            sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
             url = self.base_url + f'&expName={exp_name}'
             h = requests.get(url=url)
             content = bs(h.text, "html.parser")
@@ -264,7 +265,6 @@ class Account():
             return 0
 
     def save_experiment(self, lab_id, exp_data, version):
-        sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
         """save experiment
 
         Args:
@@ -281,16 +281,9 @@ class Account():
         正常情况：
             1.保存实验返回的结果-->exp_id
         """
-        exp_data = self.get_experiment_data(exp_data.upper())
+        exp_data = exp_data.upper()
+        exp_data = self.get_experiment_data(exp_data)
         if self.machine_name:
-            self.qcis_check.circuit = exp_data
-            res = self.qcis_check.circuit_regular()
-            if isinstance(res, bool):
-                # print('qcis verification failed, pleask check your qcis')
-                print('保存实验失败, 量子线路指令输入错误，请检查你的输入')
-                return 0
-            else:
-                exp_data = res
             url = self.base_url + '/sdk/api/multiple/experiment/detail/save'
             data = {
                 "circuit": exp_data, "lab_id": lab_id,
@@ -309,6 +302,7 @@ class Account():
                 return 0
             save_result = result.get('data').get('exp_id')
         else:
+            sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
             url = self.base_url + f'&expId={lab_id}&expData={exp_data}'
             h = requests.get(url=url)
             content = bs(h.text, "html.parser")
@@ -353,7 +347,6 @@ class Account():
         return save_result
 
     def run_experiment(self, exp_id, num_shots=12000):
-        sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
         """run experiment
 
         Args:
@@ -380,6 +373,7 @@ class Account():
                 return 0
             run_result = result.get('data').get('query_id')
         else:
+            sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
             url = self.base_url + f'&expDetailId={exp_id}&shots={num_shots}'
             h = requests.get(url=url)
             content = bs(h.text, "html.parser")
@@ -420,7 +414,8 @@ class Account():
             return 0
 
     def query_experiment(self, query_id, max_wait_time=60):
-        sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
+        if self.machine_name is None:
+            sleep(random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2))
         """query experiment
 
         Args:
@@ -449,8 +444,7 @@ class Account():
                     if code != 0:
                         print(f'查询实验失败：{msg}')
                         return 0
-                    query_exp = result.get('data').get(
-                        'experimentResults', None)
+                    query_exp = result.get('data', None)
                     if query_exp:
                         return query_exp
                 else:
@@ -473,7 +467,8 @@ class Account():
                             return query_exp
             except:
                 continue
-            sleep_time = random.randint(0, 15)*0.3+round(random.uniform(0, 1.5), 2)
+            sleep_time = random.randint(
+                0, 15)*0.3+round(random.uniform(0, 1.5), 2)
             print(f'查询实验结果请等待: {{:.2f}}秒'.format(sleep_time))
             sleep(sleep_time)
         print(f'查询实验结果失败')
@@ -481,7 +476,7 @@ class Account():
 
     def submit_job(self, circuit=None, exp_name='exp0',
                    parameters=None, values=None, num_shots=12000,
-                   lab_id=None, exp_id=None, version=None):
+                   lab_id=None, exp_id=None, version='version01'):
         """[summary]
 
         Args:
@@ -699,15 +694,34 @@ class Account():
         res = requests.post(url, json=data, headers=headers)
         status_code = res.status_code
         if status_code != 200:
-            return 0
+            raise Exception('设置机器名失败，请求接口失败')
         result = json.loads(res.text)
         code = result.get('code', -1)
         msg = result.get('msg', '设置机器名失败')
         if code != 0:
             print(f'设置机器名失败：{msg}')
-            return 0
+            raise Exception(f'设置机器名失败，{msg}')
         self.machine_name = machine_name
 
+    def download_config(self):
+        url = f'{self.base_url}/sdk/api/multiple/experiment/config/download'
+        data = {
+            "name": self.machine_name
+        }
+        headers = {"sdk_token": self.token}
+        res = requests.post(url, json=data, headers=headers)
+        status_code = res.status_code
+        if status_code != 200:
+            return 0
+        result = json.loads(res.text)
+        if 'code' in result:
+            msg = result.get('msg', '下载实验参数失败')
+            print(f'下载实验参数失败:{msg}')
+            return 0
+        with open(f'./{self.machine_name}_config_param.json', 'w') as f:
+            f.write(json.dumps(result))
+        return result
+
     def convert_qasm_to_qcis(self, qasm):
         qcis_raw = self.qasmtoqcis.convert_qasm_to_qcis(qasm)
         simplity_qcis = self.qasmtoqcis.simplify(qcis_raw)
@@ -731,190 +745,3 @@ class Account():
         simplity_qcis = self.qasmtoqcis.simplify(new_qcis_raw)
         return simplity_qcis
 
-
-if __name__ == '__main__':
-    # username = 'test03'
-    # password = '123456'
-    username = 'lixiaorong'
-    password = '12345678'
-    login_key = '2f516ffd43646ace51c38a3244b61887'
-    circuit = """
-            X  Q3
-            M  Q3
-            H Q2
-            RX   Q1 -0.146575465675675676833243244
-            RY   Q2 0.83894389688010276576575436547
-            RZ   Q4 -0.24356768782356654546576876876
-            M  Q1
-            M  Q2
-        """
-
-    qasm = """
-        OPENQASM 2.0;
-        include "qelib1.inc";
-        qreg q[10];
-        h q[1];
-        sx q[2];
-        h q[2];
-        sxdg q[3];
-        h q[2];
-        sxdg q[2];
-        h q[2];
-        x q[1];
-        y q[0];
-        t q[0];
-        tdg q[3];
-        rx(-0.8734873) q[3];
-        ry(3.052154) q[3];
-        rz(1.2546) q[3];
-        u(0.12343, -0.31323245, 0.8786834) q[3];
-        u2(0.5624, -0.12334) q[3];
-        u1(-1.23467975) q[3];
-        cx q[0],q[1];
-        cz q[0],q[1];
-        cy q[1],q[2];
-        ch q[1],q[2];
-        swap q[1],q[2];
-        crz(2.343) q[1],q[2];
-        cp(3.01234) q[1],q[2];
-        cu3(3.01234, 0.25, 1.8456) q[1],q[2];
-        h q[1];
-        sx q[1];
-        h q[1];
-        h q[3];
-        measure q[1] -> c[1];
-    """
-
-    # account = Account(login_key=login_key, machine_name='60比特量子计算实验',
-    #                   full_expr_record=True)
-    # circuit = account.convert_qasm_to_qcis_from_file('all_qasm_train/qasm_0_3.txt')
-    # print(circuit)
-
-    account = Account(username=username, password=password,
-                      full_expr_record=False)
-    # qasm1 = """
-    #         OPENQASM 2.0;
-    #         include "qelib1.inc";
-    #         qreg q[10];
-    #         rx(-2.105556545645555487820000000000000) q[1];
-    #         measure q[1] -> c[1];
-    #     """
-    circuit = '''
-        X2M Q1
-        Y2P Q1
-        X2M Q1
-        X2M Q1
-        X2M Q1
-        X2M Q1
-
-        M Q1
-    '''
-    query_id = account.submit_job(circuit, exp_name='test01')
-    print(query_id)
-    if query_id:
-        result = account.query_experiment(query_id, max_wait_time=20)
-        print(result)
-    # circuit = account.convert_qasm_to_qcis(qasm1)
-    # print(circuit)
-    # qcis = account.qcis_check_regular(circuit)
-    # print(qcis)
-    '''
-        print(account.token)
-        lab_id = account.create_experiment('test_exp_1')
-        print('lab_id:', lab_id)
-
-        exp_id = account.save_experiment(lab_id, circuit, '1.0.0')
-        print('exp_id:', exp_id)
-
-        query_id = account.run_experiment(exp_id)
-        print('query_id:', query_id)
-
-        result = account.query_experiment(query_id, max_wait_time=1)
-        print('query result:', result)
-
-        # machine_res = account.set_machine('testesst')
-        # print(machine_res)
-        lab_id = account.create_experiment('test_exp_1')
-        print('lab_id:', lab_id)
-    '''
-
-    # exp_id = account.save_experiment(lab_id, circuit, '1.0.0')
-    # print('exp_id:', exp_id)
-
-    # query_id = account.run_experiment(exp_id)
-    # print('query_id:', query_id)
-
-    # result = account.query_experiment(query_id, max_wait_time=1)
-    # print('query result:', result)
-
-    # print(account.get_experiment_data(circuit))
-
-    # 分步整体测试
-    # circuit = """
-    #         M Q1
-    #         Y Q3
-    #         M Q3
-    #         H Q2
-    #     """
-
-    # lab_id = account.create_experiment('test_exp')
-    # if lab_id:
-    #     exp_id = account.save_experiment(lab_id, circuit)
-    #     if exp_id:
-    #         query_id = account.run_experiment(exp_id)
-    #         if query_id:
-    #             print(account.query_experiment(query_id, max_wait_time=20))
-
-    # submit_job整体测试
-    #
-    # if account.login:
-    #     circuit = '''
-    #         RZ Q1 -0.494530670352271
-    #         RX Q1 -1.6604650905638
-    #         H Q1
-    #         RZ Q2 -0.155487943732828
-    #         RX Q2 -0.0137010734993274
-    #         H Q2
-    #         RZ Q3 -0.0228764841311865
-    #         RX Q3 -0.0473825532042785
-    #         H Q3
-    #         RZ Q4 -0.788912927499223
-    #         RX Q4 -0.64895063114411
-    #         H Q4
-    #         RX Q5 -1.69226448904139
-    #         H Q5
-    #         M Q1
-    #         M Q2
-    #         M Q3
-    #         M Q4
-    #         M Q5
-    #     '''
-    #
-    #     # exp_data = account.load_exp_data()
-    #     # account.exp = exp_data
-
-    #     query_id = account.submit_job(circuit, exp_name='test1_3')
-    #     if query_id:
-    #         print(account.query_experiment(query_id, max_wait_time=20))
-
-    #     query_id = account.submit_job(circuit, exp_name='test2_3')
-    #     if query_id:
-    #         print(account.query_experiment(query_id, max_wait_time=20))
-
-    #     circuit1 = """
-    #         M Q1
-    #         Y Q3
-    #         M Q3
-    #         H Q2
-    #     """
-    #     query_id = account.submit_job(circuit1, lab_id=list(account.exp.keys())[0], exp_name='test3')
-    #     if query_id:
-    #         print(account.query_experiment(query_id, max_wait_time=20))
-
-    #     lab_id = list(account.exp.keys())[0]
-    #     exp_id = list(account.exp.get(lab_id).get('exp_detail').keys())[0]
-    #     query_id = account.submit_job(lab_id=lab_id, exp_id=exp_id)
-    #     if query_id:
-    #         print(account.query_experiment(query_id, max_wait_time=20))
-
-    #     account.save_exp_data()
